@@ -8,17 +8,14 @@
 
     ## 0 - builtin SVG Cairo
     gr.cap <- capabilities()
-    if(gr.cap["cairo"]) return("builtin")
+    if(gr.cap["cairo"])
+      return("builtin")
     
     ## 1 - Find CairoDevice in the search-path
     loaded = search()
     if(length(grep("package:cairoDevice", loaded)) == 1)
       return("cairoDevice")
   
-    ## 2 - CairoDevice package available
-    ret=require("cairoDevice", quietly=TRUE)
-    if(ret) return("cairoDevice")
-  
     ## eop
     return(NULL)
   }
@@ -34,7 +31,7 @@
   ## init. check CAIRO support
   cairo <- .checkCairo()
   if(is.null(cairo))
-    warning("No SVG Cairo engine.. ('devSVGMapping' won't work)")
+    warning("No SVG Cairo engine available.. (pseudo-device disabled)")
   .set(".cairo", cairo)
 
 }
